/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLFrameElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLFrameElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLFrameElement.h"
#include "gdom/PrivateIntGdomHTMLFrameElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLFrameElement::GDOMHTMLFrameElement(PassRefPtr<WebCore::HTMLFrameElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLFrameElement.h"
#include <gdom/GdomHTMLFrameElement.h>
#include <gdom/PrivateGdomHTMLFrameElement.h>
#include <gdom/PrivateIntGdomHTMLFrameElement.h>
#include <gdom/GdomHTMLFrameElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLFrameElement, gdom_html_frame_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLFrameElementPrivate {
    class WebCore::HTMLFrameElement *item;
};

#define GDOM_HTML_FRAME_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_FRAME_ELEMENT, GdomHTMLFrameElementPrivate))
*/
G_END_DECLS
WebCore::HTMLFrameElement *
gdom_html_frame_element_get_private(GdomHTMLFrameElement *request)
{
    GDOMHTMLFrameElement *res;
    res = static_cast<GDOMHTMLFrameElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLFrameElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_FRAME_BORDER,
    PROP_LONG_DESC,
    PROP_MARGIN_HEIGHT,
    PROP_MARGIN_WIDTH,
    PROP_NAME,
    PROP_NO_RESIZE,
    PROP_SCROLLING,
    PROP_SRC,
    PROP_CONTENT_DOCUMENT,
    PROP_CONTENT_WINDOW,
    PROP_LOCATION,
    PROP_WIDTH,
    PROP_HEIGHT,
};


static void gdom_html_frame_element_finalize(GObject* object)
{
    /*GdomHTMLFrameElement* request = GDOM_HTML_FRAME_ELEMENT(object);*/
    /*GdomHTMLFrameElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_frame_element_parent_class)->finalize(object);
}

static void gdom_html_frame_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLFrameElement *self = GDOM_HTML_FRAME_ELEMENT(object);
    WebCore::HTMLFrameElement * gself = (gdom_html_frame_element_get_private(self));
    switch (prop_id) {
     case PROP_FRAME_BORDER:
    {
         gself->setFrameBorder(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_LONG_DESC:
    {
         gself->setLongDesc(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_MARGIN_HEIGHT:
    {
         gself->setMarginHeight(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_MARGIN_WIDTH:
    {
         gself->setMarginWidth(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_NAME:
    {
         gself->setName(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_NO_RESIZE:
    {
         gself->setNoResize((g_value_get_boolean (value)) );
         break;
    }
     case PROP_SCROLLING:
    {
         gself->setScrolling(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_SRC:
    {
         gself->setSrc(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_LOCATION:
    {
         gself->setLocation(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_frame_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLFrameElement *self = GDOM_HTML_FRAME_ELEMENT(object);
    WebCore::HTMLFrameElement * gself = (gdom_html_frame_element_get_private(self));
    switch (prop_id) {
    case PROP_FRAME_BORDER:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->frameBorder()));
         break;
    }
    case PROP_LONG_DESC:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->longDesc()));
         break;
    }
    case PROP_MARGIN_HEIGHT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->marginHeight()));
         break;
    }
    case PROP_MARGIN_WIDTH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->marginWidth()));
         break;
    }
    case PROP_NAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->name()));
         break;
    }
    case PROP_NO_RESIZE:
    {
         g_value_set_boolean (value, gself->noResize());
         break;
    }
    case PROP_SCROLLING:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->scrolling()));
         break;
    }
    case PROP_SRC:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->src()));
         break;
    }
    case PROP_CONTENT_DOCUMENT:
    {
         PassRefPtr<WebCore::Document> ptr = gself->contentDocument();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_CONTENT_WINDOW:
    {
         PassRefPtr<WebCore::DOMWindow> ptr = gself->contentWindow();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_LOCATION:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->location()));
         break;
    }
    case PROP_WIDTH:
    {
         g_value_set_long (value, gself->width());
         break;
    }
    case PROP_HEIGHT:
    {
         g_value_set_long (value, gself->height());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_frame_element_class_init(GdomHTMLFrameElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_frame_element_finalize;
    g_klass->set_property = gdom_html_frame_element__set_property_fn;
    g_klass->get_property = gdom_html_frame_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_FRAME_BORDER,
            g_param_spec_string ("frame_border", /* name */
                "html_frame_element_frame_border", /* short description */
                "read-write  gchar * HTMLFrameElement.frame_border", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_LONG_DESC,
            g_param_spec_string ("long_desc", /* name */
                "html_frame_element_long_desc", /* short description */
                "read-write  gchar * HTMLFrameElement.long_desc", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_MARGIN_HEIGHT,
            g_param_spec_string ("margin_height", /* name */
                "html_frame_element_margin_height", /* short description */
                "read-write  gchar * HTMLFrameElement.margin_height", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_MARGIN_WIDTH,
            g_param_spec_string ("margin_width", /* name */
                "html_frame_element_margin_width", /* short description */
                "read-write  gchar * HTMLFrameElement.margin_width", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_NAME,
            g_param_spec_string ("name", /* name */
                "html_frame_element_name", /* short description */
                "read-write  gchar * HTMLFrameElement.name", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_NO_RESIZE,
            g_param_spec_boolean ("no_resize", /* name */
                "html_frame_element_no_resize", /* short description */
                "read-write  gboolean HTMLFrameElement.no_resize", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SCROLLING,
            g_param_spec_string ("scrolling", /* name */
                "html_frame_element_scrolling", /* short description */
                "read-write  gchar * HTMLFrameElement.scrolling", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SRC,
            g_param_spec_string ("src", /* name */
                "html_frame_element_src", /* short description */
                "read-write  gchar * HTMLFrameElement.src", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CONTENT_DOCUMENT,
            g_param_spec_object ("content_document", /* name */
                "html_frame_element_content_document", /* short description */
                "read-only  GdomDocument * HTMLFrameElement.content_document", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_DOCUMENT, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_CONTENT_WINDOW,
            g_param_spec_object ("content_window", /* name */
                "html_frame_element_content_window", /* short description */
                "read-only  GdomDOMWindow * HTMLFrameElement.content_window", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_DOM_WINDOW, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_LOCATION,
            g_param_spec_string ("location", /* name */
                "html_frame_element_location", /* short description */
                "read-write  gchar * HTMLFrameElement.location", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_WIDTH,
            g_param_spec_long ("width", /* name */
                "html_frame_element_width", /* short description */
                "read-only  glong HTMLFrameElement.width", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_HEIGHT,
            g_param_spec_long ("height", /* name */
                "html_frame_element_height", /* short description */
                "read-only  glong HTMLFrameElement.height", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLFrameElementPrivate));*/
}

static void gdom_html_frame_element_init(GdomHTMLFrameElement* request)
{
    /*GdomHTMLFrameElementPrivate* priv = GDOM_HTML_FRAME_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

